EXPORTS
	__27CBaseSmsActiveSocketWatcherR11CWatcherLogiG4TUidR3RFs @ 1 NONAME ; CBaseSmsActiveSocketWatcher::CBaseSmsActiveSocketWatcher(CWatcherLog &, int, TUid, RFs &)
	CompleteMyself__15CSmsBaseWatcheri @ 2 NONAME R3UNUSED ; CSmsBaseWatcher::CompleteMyself(int)
	Complete__27CBaseSmsActiveSocketWatcheri @ 3 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::Complete(int)
	ConstructL__15CSmsBaseWatcher @ 4 NONAME R3UNUSED ; CSmsBaseWatcher::ConstructL(void)
	ConstructL__27CBaseSmsActiveSocketWatcherR12CBIODatabase @ 5 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::ConstructL(CBIODatabase &)
	CreateSocketWatchersFromBioDbL__15CSmsBaseWatcher13TBioMsgIdType @ 6 NONAME R3UNUSED ; CSmsBaseWatcher::CreateSocketWatchersFromBioDbL(TBioMsgIdType)
	CreateSocketWatchersFromBioDbL__15CSmsBaseWatcher13TBioMsgIdTypeG4TUid @ 7 NONAME R3UNUSED ; CSmsBaseWatcher::CreateSocketWatchersFromBioDbL(TBioMsgIdType, TUid)
	DeleteBifL__15CSmsBaseWatcherG4TUid @ 8 NONAME R3UNUSED ; CSmsBaseWatcher::DeleteBifL(TUid)
	DeleteSocketWatchersWithUidL__15CSmsBaseWatcherG4TUid @ 9 NONAME R3UNUSED ; CSmsBaseWatcher::DeleteSocketWatchersWithUidL(TUid)
	DoCancel__15CSmsBaseWatcher @ 10 NONAME R3UNUSED ; CSmsBaseWatcher::DoCancel(void)
	HandleBifChangeL__15CSmsBaseWatcherQ218MBifChangeObserver15TBifChangeEventG4TUid @ 11 NONAME R3UNUSED ; CSmsBaseWatcher::HandleBifChangeL(MBifChangeObserver::TBifChangeEvent, TUid)
	HandleWatcherComplete__15CSmsBaseWatcherR27CBaseSmsActiveSocketWatcheri @ 12 NONAME R3UNUSED ; CSmsBaseWatcher::HandleWatcherComplete(CBaseSmsActiveSocketWatcher &, int)
	ReloadBifL__15CSmsBaseWatcherG4TUid @ 13 NONAME R3UNUSED ; CSmsBaseWatcher::ReloadBifL(TUid)
	ResetDb__15CSmsBaseWatcher @ 14 NONAME R3UNUSED ; CSmsBaseWatcher::ResetDb(void)
	Reset__15CSmsBaseWatcher @ 15 NONAME R3UNUSED ; CSmsBaseWatcher::Reset(void)
	RestoreSettingsL__27CBaseSmsActiveSocketWatcherR11CMsvSession @ 16 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::RestoreSettingsL(CMsvSession &)
	RunError__15CSmsBaseWatcheri @ 17 NONAME R3UNUSED ; CSmsBaseWatcher::RunError(int)
	RunError__27CBaseSmsActiveSocketWatcheri @ 18 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::RunError(int)
	RunL__15CSmsBaseWatcher @ 19 NONAME R3UNUSED ; CSmsBaseWatcher::RunL(void)
	RunL__27CBaseSmsActiveSocketWatcher @ 20 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::RunL(void)
	SetBioMsgText__27CBaseSmsActiveSocketWatcherR12CBIODatabase @ 21 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::SetBioMsgText(CBIODatabase &)
	SetupAndAppendL__15CSmsBaseWatcherR27CBaseSmsActiveSocketWatcherRt13CArrayPtrFlat1Z27CBaseSmsActiveSocketWatcher @ 22 NONAME R3UNUSED ; CSmsBaseWatcher::SetupAndAppendL(CBaseSmsActiveSocketWatcher &, CArrayPtrFlat<CBaseSmsActiveSocketWatcher> &)
	SetupL__27CBaseSmsActiveSocketWatcher @ 23 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::SetupL(void)
	StartL__15CSmsBaseWatcher @ 24 NONAME R3UNUSED ; CSmsBaseWatcher::StartL(void)
	StartL__27CBaseSmsActiveSocketWatcher @ 25 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::StartL(void)
	StartSocketWatchersL__15CSmsBaseWatcher @ 26 NONAME R3UNUSED ; CSmsBaseWatcher::StartSocketWatchersL(void)
	StoreMsgL__27CBaseSmsActiveSocketWatcherP11CSmsMessage @ 27 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::StoreMsgL(CSmsMessage *)
	"_._15CSmsBaseWatcher" @ 28 NONAME R3UNUSED ; CSmsBaseWatcher::~CSmsBaseWatcher(void)
	"_._27CBaseSmsActiveSocketWatcher" @ 29 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::~CBaseSmsActiveSocketWatcher(void)
	__15CSmsBaseWatcherR3RFsR11CWatcherLogi @ 30 NONAME ; CSmsBaseWatcher::CSmsBaseWatcher(RFs &, CWatcherLog &, int)
	AddBifWithTypeL__15CSmsBaseWatcher13TBioMsgIdTypeG4TUid @ 31 NONAME R3UNUSED ; CSmsBaseWatcher::AddBifWithTypeL(TBioMsgIdType, TUid)
	PreStoreActionL__27CBaseSmsActiveSocketWatcherR11CMsvSessionR11CSmsMessage @ 32 NONAME R3UNUSED ; CBaseSmsActiveSocketWatcher::PreStoreActionL(CMsvSession &, CSmsMessage &)

